@@ -5,22 +5,23 @@ import (
 )
 
 type Template struct {
-	SegmentsCache maps.Simple
-	Segments      *maps.Concurrent
-	Var           maps.Simple
-	ShellVersion  string
-	AbsolutePWD   string
+	SegmentsCache maps.Simple[any]
+	Segments      *maps.Concurrent[any]
+	Var           maps.Simple[any]
+	PWD           string
+	Folder        string
 	PSWD          string
 	UserName      string
 	HostName      string
-	PWD           string
+	ShellVersion  string
 	Shell         string
-	Folder        string
+	AbsolutePWD   string
 	OS            string
-	Code          int
+	Version       string
 	PromptCount   int
 	SHLVL         int
 	Jobs          int
+	Code          int
 	WSL           bool
 	Root          bool
 }
