@@ -63,7 +63,7 @@ func (k *Kubectl) doParseKubeConfig() bool {
 	k.Context = ""
 
 	for _, kubeconfig := range kubeconfigs {
-		if len(kubeconfig) == 0 {
+		if kubeconfig == "" {
 			continue
 		}
 
@@ -81,7 +81,7 @@ func (k *Kubectl) doParseKubeConfig() bool {
 			}
 		}
 
-		if len(k.Context) == 0 {
+		if k.Context == "" {
 			k.Context = config.CurrentContext
 		}
 
@@ -143,7 +143,7 @@ func (k *Kubectl) doCallKubectl() bool {
 }
 
 func (k *Kubectl) setError(message string) {
-	if len(k.Context) == 0 {
+	if k.Context == "" {
 		k.Context = message
 	}
 
